==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AssociatedServerMediated.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AssociatedServerMediated
 */
@JsonPropertyOrder({ AssociatedServerMediated.JSON_PROPERTY_TRUSTED })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AssociatedServerMediated implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TRUSTED = "trusted";
    private List<String> trusted = null;

    public AssociatedServerMediated() {
    }

    public AssociatedServerMediated trusted(List<String> trusted) {

        this.trusted = trusted;
        return this;
    }

    public AssociatedServerMediated addtrustedItem(String trustedItem) {
        if (this.trusted == null) {
            this.trusted = new ArrayList<>();
        }
        this.trusted.add(trustedItem);
        return this;
    }

    /**
     * A list of the authorization server IDs
     *
     * @return trusted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of the authorization server IDs")
    @JsonProperty(JSON_PROPERTY_TRUSTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getTrusted() {
        return trusted;
    }

    @JsonProperty(JSON_PROPERTY_TRUSTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrusted(List<String> trusted) {
        this.trusted = trusted;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AssociatedServerMediated associatedServerMediated = (AssociatedServerMediated) o;
        return Objects.equals(this.trusted, associatedServerMediated.trusted);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(trusted);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AssociatedServerMediated {\n");
        sb.append("    trusted: ").append(toIndentedString(trusted)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/AssociatedServerMediated.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AssociatedServerMediated
 */
@JsonPropertyOrder({ AssociatedServerMediated.JSON_PROPERTY_TRUSTED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AssociatedServerMediated implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TRUSTED = "trusted";
    private List<String> trusted = null;

    public AssociatedServerMediated() {
    }

    public AssociatedServerMediated trusted(List<String> trusted) {

        this.trusted = trusted;
        return this;
    }

    public AssociatedServerMediated addtrustedItem(String trustedItem) {
        if (this.trusted == null) {
            this.trusted = new ArrayList<>();
        }
        this.trusted.add(trustedItem);
        return this;
    }

    /**
     * A list of the authorization server IDs
     *
     * @return trusted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of the authorization server IDs")
    @JsonProperty(JSON_PROPERTY_TRUSTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getTrusted() {
        return trusted;
    }

    @JsonProperty(JSON_PROPERTY_TRUSTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrusted(List<String> trusted) {
        this.trusted = trusted;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AssociatedServerMediated associatedServerMediated = (AssociatedServerMediated) o;
        return Objects.equals(this.trusted, associatedServerMediated.trusted);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(trusted);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AssociatedServerMediated {\n");
        sb.append("    trusted: ").append(toIndentedString(trusted)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
